@@ -31,20 +31,20 @@ function(x, plainleaf = TRUE)
     
     nval <- matrix(rep.int("", 2L * length(nodes)), ncol = 2L)
     colnames(nval) <- c("name", "splitvar")
-    nval[, 1L] <- sapply(strsplit(nodes, " "), "[", 1L)
-    nval[, 2L] <- sapply(strsplit(nodes, "\""), "[", 2L)
+    nval[, 1L] <- sapply(strsplit(nodes, " "), `[`, 1L)
+    nval[, 2L] <- sapply(strsplit(nodes, "\""), `[`, 2L)
     if(plainleaf)
         nval[grep("(", nval[, 2L], fixed = TRUE), 2L] <- ""
     
     eval <- matrix(rep.int("", 3L * length(edges)), ncol = 3L)
     colnames(eval) <- c("from", "to", "label")
-    eval[, 1L] <- sapply(strsplit(edges, "->"), "[", 1L)
+    eval[, 1L] <- sapply(strsplit(edges, "->"), `[`, 1L)
     eval[, 2L] <-
         sapply(strsplit(as.character(sapply(strsplit(edges, "->"),
-                                            "[", 2L)),
+                                            `[`, 2L)),
                         " "),
-               "[", 1L)
-    eval[, 3L] <- sapply(strsplit(edges, "\""), "[", 2L)
+               `[`, 1L)
+    eval[, 3L] <- sapply(strsplit(edges, "\""), `[`, 2L)
     
     return(list(nodes = nval, edges = eval))
 }
